@@ -650,8 +650,8 @@ static const yytype_uint16 yyrline[] =
      605,   607,   609,   611,   613,   615,   619,   621,   623,   625,
      627,   629,   631,   633,   637,   639,   643,   647,   654,   662,
      671,   682,   689,   696,   703,   714,   715,   718,   720,   724,
-     739,   743,   750,   751,   754,   755,   758,   761,   764,   767,
-     768,   771,   774,   775,   778
+     725,   726,   733,   734,   737,   738,   741,   744,   747,   750,
+     751,   754,   757,   758,   761
 };
 #endif
 
@@ -2143,10 +2143,10 @@ yyreduce:
     {
 			    if ((yyvsp[(1) - (2)].uval)==MergeAltForm) {
 				yyerror("cannot use 'alternate' to include other maps");
-				(yyval.any)= &IncludeCreate(scanStr,MergeDefault)->common;
+				(yyval.any)= &IncludeCreate(scanBuf,MergeDefault)->common;
 			    }
 			    else {
-				(yyval.any)= &IncludeCreate(scanStr,(yyvsp[(1) - (2)].uval))->common;
+				(yyval.any)= &IncludeCreate(scanBuf,(yyvsp[(1) - (2)].uval))->common;
 			    }
                         }
     break;
@@ -2224,12 +2224,12 @@ yyreduce:
 
   case 60:
 #line 377 "xkbparse.y"
-    { (yyval.interp)= InterpCreate((KeySym)(yyvsp[(1) - (3)].uval),(yyvsp[(3) - (3)].expr)); }
+    { (yyval.interp)= InterpCreate(XStringToKeysym((yyvsp[(1) - (3)].str)), (yyvsp[(3) - (3)].expr)); }
     break;
 
   case 61:
 #line 379 "xkbparse.y"
-    { (yyval.interp)= InterpCreate((KeySym)(yyvsp[(1) - (1)].uval),NULL); }
+    { (yyval.interp)= InterpCreate(XStringToKeysym((yyvsp[(1) - (1)].str)), NULL); }
     break;
 
   case 62:
@@ -2819,115 +2819,100 @@ yyreduce:
 
   case 167:
 #line 719 "xkbparse.y"
-    { (yyval.expr)= AppendKeysymList((yyvsp[(1) - (3)].expr),(KeySym)(yyvsp[(3) - (3)].uval)); }
+    { (yyval.expr)= AppendKeysymList((yyvsp[(1) - (3)].expr),(yyvsp[(3) - (3)].str)); }
     break;
 
   case 168:
 #line 721 "xkbparse.y"
-    { (yyval.expr)= CreateKeysymList((KeySym)(yyvsp[(1) - (1)].uval)); }
+    { (yyval.expr)= CreateKeysymList((yyvsp[(1) - (1)].str)); }
     break;
 
   case 169:
-#line 725 "xkbparse.y"
-    { 
-			    KeySym sym;
-			    if (LookupKeysym(scanStr,&sym))
-				(yyval.uval)= sym;
-			    else {
-				char buf[120];
-				snprintf(buf, sizeof(buf),
-					 "expected keysym, got %s",
-					 uStringText(scanStr));
-				yyerror(buf);
-				yynerrs++;
-				(yyval.uval)= NoSymbol;
-			    }
-			}
+#line 724 "xkbparse.y"
+    { (yyval.str)= strdup(scanBuf); }
     break;
 
   case 170:
-#line 740 "xkbparse.y"
-    {
-			    (yyval.uval)= XK_section;
-			}
+#line 725 "xkbparse.y"
+    { (yyval.str)= strdup("section"); }
     break;
 
   case 171:
-#line 744 "xkbparse.y"
+#line 727 "xkbparse.y"
     {
-			    if ((yyvsp[(1) - (1)].ival)<10)	(yyval.uval)= (yyvsp[(1) - (1)].ival)+'0';	/* XK_0 .. XK_9 */
-			    else	(yyval.uval)= (yyvsp[(1) - (1)].ival);
+			    if ((yyvsp[(1) - (1)].ival)<10)	{ (yyval.str)= malloc(2); (yyval.str)[0]= '0' + (yyvsp[(1) - (1)].ival); (yyval.str)[1]= '\0'; }
+			    else	{ (yyval.str)= malloc(19); snprintf((yyval.str), 19, "0x%x", (yyvsp[(1) - (1)].ival)); }
 			}
     break;
 
   case 172:
-#line 750 "xkbparse.y"
+#line 733 "xkbparse.y"
     { (yyval.ival)= -(yyvsp[(2) - (2)].ival); }
     break;
 
   case 173:
-#line 751 "xkbparse.y"
+#line 734 "xkbparse.y"
     { (yyval.ival)= (yyvsp[(1) - (1)].ival); }
     break;
 
   case 174:
-#line 754 "xkbparse.y"
+#line 737 "xkbparse.y"
     { (yyval.ival)= scanInt; }
     break;
 
   case 175:
-#line 755 "xkbparse.y"
+#line 738 "xkbparse.y"
     { (yyval.ival)= scanInt*XkbGeomPtsPerMM; }
     break;
 
   case 176:
-#line 758 "xkbparse.y"
+#line 741 "xkbparse.y"
     { (yyval.ival)= scanInt; }
     break;
 
   case 177:
-#line 761 "xkbparse.y"
+#line 744 "xkbparse.y"
     { (yyval.ival)= scanInt; }
     break;
 
   case 178:
-#line 764 "xkbparse.y"
-    { (yyval.str)= scanStr; scanStr= NULL; }
+#line 747 "xkbparse.y"
+    { (yyval.str)= strdup(scanBuf); }
     break;
 
   case 179:
-#line 767 "xkbparse.y"
-    { (yyval.sval)= XkbInternAtom(NULL,scanStr,False); }
+#line 750 "xkbparse.y"
+    { (yyval.sval)= XkbInternAtom(NULL,scanBuf,False); }
     break;
 
   case 180:
-#line 768 "xkbparse.y"
+#line 751 "xkbparse.y"
     { (yyval.sval)= XkbInternAtom(NULL,"default",False); }
     break;
 
   case 181:
-#line 771 "xkbparse.y"
-    { (yyval.sval)= XkbInternAtom(NULL,scanStr,False); }
+#line 754 "xkbparse.y"
+    { (yyval.sval)= XkbInternAtom(NULL,scanBuf,False); }
     break;
 
   case 182:
-#line 774 "xkbparse.y"
+#line 757 "xkbparse.y"
     { (yyval.str)= (yyvsp[(1) - (1)].str); }
     break;
 
   case 183:
-#line 775 "xkbparse.y"
+#line 758 "xkbparse.y"
     { (yyval.str)= NULL; }
     break;
 
   case 184:
-#line 778 "xkbparse.y"
-    { (yyval.str)= scanStr; scanStr= NULL; }
+#line 761 "xkbparse.y"
+    { (yyval.str)= strdup(scanBuf); }
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 2931 "xkbparse.c"
+#line 2916 "xkbparse.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -3141,7 +3126,7 @@ yyreturn:
 }
 
 
-#line 780 "xkbparse.y"
+#line 763 "xkbparse.y"
 
 void
 yyerror(const char *s)
@@ -3149,8 +3134,8 @@ yyerror(const char *s)
     if (warningLevel>0) {
 	(void)fprintf(stderr,"%s: line %d of %s\n",s,lineNum,
 					(scanFile?scanFile:"(unknown)"));
-	if ((scanStr)&&(warningLevel>3))
-	    (void)fprintf(stderr,"last scanned symbol is: %s\n",scanStr);
+	if ((warningLevel>3))
+	    (void)fprintf(stderr,"last scanned symbol is: %s\n",scanBuf);
     }
     return;
 }
